@@ -123,10 +123,17 @@ def exists(file_path, **kwargs):
     '''
         Confirms that the file exists.
 
+        Arguments
         ----------
         `file_path` {str}
             The file path to test.
 
+        Keyword Arguments
+        -------------------------
+        [`ftp`=None] {bool}
+            A reference to the ftputil object to use.
+
+
         ----------
         `return` {bool}
             True if the file exists, False otherwise.
@@ -161,6 +168,8 @@ def delete(file_path, **kwargs):
         -------------------------
         [`shred`=False] {bool}
             if True, the file is shredded and securely deleted.
+        [`ftp`=None] {object}
+            A reference to the ftputil object to use.
 
         Return {bool}
         ----------------------
@@ -283,7 +292,37 @@ def _parse_copy_data_from_obj(file_obj):
     return data
 
 
-def rename(src_path, dst_path):
+def rename(src_path, dst_path, ftp=None):
+    '''
+        Rename a file on the local machine or on an FTP server.
+
+        ----------
+
+        Arguments
+        -------------------------
+        `src_path` {str}
+            The path to the file to rename
+        `dst_path` {str}
+            The new path for the file.
+        [`ftp`=None] {object}
+            A reference to the ftputil object to use.
+
+
+        Return {bool}
+        ----------------------
+        True upon success, false otherwise.
+
+        Meta
+        ----------
+        `author`: Colemen Atwood
+        `created`: 12-17-2021 16:47:49
+        `memberOf`: file
+        `version`: 1.0
+        `method_name`: rename
+    '''
+    if ftp is not None:
+        ftp.rename(src_path, dst_path)
+        return True
     success = False
     if exists(src_path):
         os.rename(src_path, dst_path)
@@ -408,8 +447,8 @@ def _delete_single_file(file_path, shred=False, ftp=None):
             Path to the file to delete.
         [`shred`=False] {bool}
             Securely shred the file (slower)
-        [`ftp`=None] {ftputil object}
-            The ftp object to use.
+        [`ftp`=None] {object}
+            A reference to the ftputil object to use.
 
         Return {bool}
         ----------------------
@@ -511,28 +550,6 @@ def _thread_file_action(file_list, **kwargs):
     return
 
 
-# def get_modtime_size(file_path, **kwargs):
-#     data_include = obj.get_kwarg(['include', "data include"], [], (list, str), **kwargs)
-#     if isinstance(data_include, (str)):
-#         data_include = [data_include]
-#     file_path = strUtils.format.file_path(file_path)
-#     if exists(file_path):
-#         # print(f"file exists: {file_path}")
-#         # print(f"Getting data for file: {file_path}")
-#         try:
-#             file_data = {}
-#             file_data['file_path'] = file_path
-#             file_data['modified_time'] = get_modified_time(file_path)
-#             file_data['size'] = os.path.getsize(file_path)
-
-#             return file_data
-#         except FileNotFoundError as error:
-#             logger.warning(f"Error: {error}")
-#             return None
-#     else:
-#         logger.warning(f"Failed to find the file: {file_path}")
-
-
 def get_data(file_path, **kwargs):
     '''
         Get data associated to the file_path provided.
@@ -564,7 +581,6 @@ def get_data(file_path, **kwargs):
         `version`: 1.0
         `method_name`: get_data
     '''
-
     ftp = obj.get_kwarg(['ftp'], None, None, **kwargs)
     if ftp is not None:
         file_data = {}
